@@ -3,6 +3,8 @@
 In case of chrome update it will automatically download the new compatible
 webdriver version.
 """
+from .chrome_driver import *
+from .cli import *
 
 __author__ = "Frederico Gago"
 __copyright__ = "Copyright (C) 2022 by Frederico Gago"
