@@ -1,6 +1,6 @@
 import argparse
 
-from chrome_driver import ChromeDriver
+from src import ChromeDriver
 
 
 def main():
@@ -24,8 +24,3 @@ def main():
 
 if __name__ == "__main__":
     main()
-
-
-
-if __name__ == "__main__":
-    main()
